@@ -40,12 +40,3 @@ class Daemon:
             )
         await self._worker.run()
         logger.debug("AIOKafkaDaemon stopped")
-
-
-def main():
-    daemon = Daemon()
-    daemon.run()
-
-
-if __name__ == "__main__":
-    main()
